@@ -1,5 +1,5 @@
 package Apache::LogRegex;
-$Apache::LogRegex::VERSION = '1.70';
+$Apache::LogRegex::VERSION = '1.71';
 use strict;
 use warnings;
 
@@ -24,44 +24,60 @@ sub new {
 sub _parse_format {
     my ($self) = @_;
 
+    sub quoted_p {
+        $_[0] =~ m/^\\\"/;
+    }
+
     chomp $self->{_format};
     $self->{_format} =~ s#[ \t]+# #;
     $self->{_format} =~ s#^ ##;
     $self->{_format} =~ s# $##;
 
-    my @regex_elements;
+    my @format_elements = split /\s+/, $self->{_format};
+    my $regex_string = '';
 
-    for my $element (split /\s+/, $self->{_format}) {
-        my $quotes = $element =~ m/^\\\"/ ? 1 : 0;
+    for (my $i = 0; $i < @format_elements; $i++) {
+        my $element = $format_elements[$i];
+        my $quoted = quoted_p($element);
 
-        if ($quotes) {
+        if ($quoted) {
             $element =~ s/^\\\"//;
             $element =~ s/\\\"$//;
         }
 
         push @{ $self->{_regex_fields} }, $self->rename_this_name($element);
 
-        my $x = '(\S*)';
+        my $group = '(\S*)';
 
-        if ($quotes) {
+        if ($quoted) {
             if ($element eq '%r' or $element =~ m/{Referer}/ or $element =~ m/{User-Agent}/) {
-                $x = qr/"([^"\\]*(?:\\.[^"\\]*)*)"/;
+                $group = qr/"([^"\\]*(?:\\.[^"\\]*)*)"/;
             }
             else {
-                $x = '\"([^\"]*)\"';
+                $group = '\"([^\"]*)\"';
             }
         }
         elsif ($element =~ m/^%.*t$/) {
-            $x = '(\[[^\]]+\])';
+            $group = '(\[[^\]]+\])';
         }
         elsif ($element eq '%U') {
-            $x = '(.+?)';
+            $group = '(.+?)';
         }
 
-        push @regex_elements, $x;
+        $regex_string .= $group;
+
+        # expect elements separated by whitespace
+        if ($i < $#format_elements) {
+            my $next_element = $format_elements[$i + 1];
+            if ($quoted && quoted_p($next_element)) {
+                # tolerate multiple whitespaces iff both elements are quoted
+                $regex_string .= '\s+';
+            } else {
+                $regex_string .= '\s';
+            }
+        }
     }
 
-    my $regex_string = join '\s+', @regex_elements;
     $self->{_regex} = qr/^$regex_string\s*$/;
 }
 
@@ -139,7 +155,7 @@ Apache::LogRegex - Parse a line from an Apache logfile into a hash
 
 =head1 VERSION
 
-version 1.70
+version 1.71
 
 =head1 SYNOPSIS
 
@@ -174,8 +190,8 @@ version 1.70
 
 =head2 Overview
 
-Designed as a simple class to parse Apache log files. It will construct
-a regex that will parse the given log file format and can then parse
+A simple class to parse Apache access log files. It will construct a
+regex that will parse the given log file format and can then parse
 lines from the log file line by line returning a hash of each line.
 
 The field names of the hash are derived from the log file format. Thus if
@@ -186,9 +202,9 @@ Should these key names be unusable, as I guess they probably are, then subclass
 and provide an override rename_this_name() method that can rename the keys
 before they are added in the array of field names.
 
-This module supports variable spacing between elements, so if you have
-more than one space between elements in your format or in your log
-file, that should be OK.
+This module supports variable spacing between elements that are
+surrounded by quotes, so if you have more than one space between those
+elements in your format or in your log file, that should be OK.
 
 =head1 SUBROUTINES/METHODS
 
